@@ -1,4 +1,5 @@
 ### reader component
+### 1. is a subclass of a Component (== OnePassBitmapAlgorithmComponent.pm)
 
 use parent 'OnePassBitmapAlgorithmComponent';
 
@@ -7,26 +8,32 @@ sub new {
 
     $self = SUPER::OnePassBitmapAlgorithmComponent->new;
 
-    ### 1. data is temporary output of the functor for example
-    ### 2. operand is the class on which the functor works
-    $self = { data => undef, op => undef, index => -1, };
+    ### 1. matrixbitmap is temporary output of the functor for example
+    $self = { matrixbitmap => undef, };
     
     bless $self, $class;
 }
 
+### returns matrix of the loaded bitmap
+sub getBitmap {
+  my $self = shift;
+
+  return $self->{matrixbitmap};
+}
+
 sub addLoadPNG {
     my ($self) = @_;
     
     my $loader = MatrixBitmapLoader->new;
 
-    ### sets index
-    $self->{index} = $self->addFunctor(OnePassFunctor->new(&$loader->loadPNGFile));
+    ### NOTE : uses WithClassOp, sets index (the base class only contains 1 idx)
+    my $self->{index} = $self->addFunctor(OnePassFunctorWithClassOp->new(&$loader->loadPNGFile));
     ### sets class on which this operates
-    $self->{op} = \$loader;
     $self->indexFunctor($i)->setClassOp(\$loader);
 }
 
-sub exec {
+### This Component only has one function in the functors list
+sub executeAllFunctors {
     my ($self, $filename) = @_;
 
     my $result = $self->indexFunctor($self->{index})->do($filename);
@@ -35,3 +42,4 @@ sub exec {
 
 }
     
+1;
