@@ -3,15 +3,15 @@
 sub new {
     my $class = shift;
 
-    $self = { bitmap => undef, componentsbag => undef };
+    $self = { bitmapmatrix => undef, componentsbag => undef };
     
     bless $self, $class;
 }
 
 sub init {
-    my ($self, $bitmap) = @_;
+    my ($self, $bitmapmatrix) = @_;
 
-    $self->{bitmap} = $bitmap;
+    $self->{bitmapmatrix} = $bitmapmatrix;
     $self->{componentsbag} = OnePassBitmapAlgorithmComponentsBag->new;
 }
 
@@ -19,7 +19,7 @@ sub init {
 sub getBitmap {
   my $self = shift;
 
-  return $self->{bitmap};
+  return $self->{bitmapmatrix};
 }
 
 sub getBag {
@@ -28,6 +28,11 @@ sub getBag {
   return $self->{componentsbag};
 }
 
+sub addToBag {
+  my ($self, $bagel) = @_;
+
+  
+
 sub pass {
     my ($self, $onepasssystem) = @_;
 
