@@ -16,8 +16,7 @@ sub addFunctor {
 
     $self->{functors}->add($f);
 
-    ### return last index
-    return len($self->{functors}->len - 1); ### FIXME 
+    return len($self->{functors}->len - 1); ### returns last index of functor list
 }
 
 sub indexFunctor {
@@ -27,19 +26,21 @@ sub indexFunctor {
 }
 
 ### iterates over functors and executes them in the list order
+### 1. the bitmaparg gets set every cycle as all functors update the previous one
 sub executeAllFunctors {
-    my ($self, $args) = @_;
+    my ($self, $bitmaparg) = @_;
  
     my $iter = toolsarray->new($self->{functors});
 
     while ($iter->hasNext) {
 
-	my $res = $iter->next->do($args);
-	$iter->current->setResult($res);
+	my $resultbitmap = $iter->next->do($bitmaparg); ### FIXME next ?
+	$iter->current->setResult($resultbitmap);
 
+	$bitmaparg = $resultbitmap; ### update bitmap further in the list
     }
     
-    return 0;
+    return 0; ### NOTE C lang
 }
 
 1;
