@@ -1,4 +1,4 @@
-### Blue dither algorithm
+### Blue dither algorithm, real filter
 
 use parent 'OnePassBitmapAlgorithm';
 
@@ -9,7 +9,7 @@ sub new {
     
     bless $self, $class;
 
-    $self->init; ### sets bitmap undef
+    $self->init; ### sets bitmap undef, componentsbag new
 }
 
 sub addBitmap { ### sets bitmap
@@ -23,6 +23,13 @@ sub addBitmap { ### sets bitmap
 sub pass {
   my $self = shift;
 
+  ######### FIXME TODO
+  
+  ### 1 of el1 means one follower
+  my $secondel1 = MatrixBitmapLoaderComponent->new;
+  my $firstel1 = BagElement->new->setNext($secondel1);
+  $self->addBagElement1($firstel1);
+  
   return SUPER::OnePassBitmapAlgorithm->pass->(OnePassSystemBlue->new); 
 }
 
