@@ -14,15 +14,15 @@ sub new {
 
 
 sub run {
-    my ($self, $algo, $functorsargs) = @_;
+    my ($self, $algo) = @_;
 
     my $componentsbag = $algo->getBag;
-    my $bitmap = $algo->getBitmap;
+    my $matrixbitmap = $algo->getBitmap;
 
     my $bagelement1 = $componentsbag->getBagElement1;
 
     ### FIXME ? ->
-    not $bagelement1->executeAllFunctors($functorsargs) or die "OnePassSystemBlue : Something went wrong executing your functors list of the first bag element, your bitmap may be incomplete.\n"; 
+    not $bagelement1->executeAllFunctors($matrixbitmap) or die "OnePassSystemBlue : Something went wrong executing your functors list of the first bag element, your bitmap may be incomplete.\n"; 
 }
 
 1;
